@@ -38,7 +38,7 @@ import logging
 
 from .scms import scms, subversion, git, mercurial, bazaar
 
-from cuppa.colourise import as_notice, as_info, as_warning, as_error, as_info_label, as_error_label
+from cuppa.colourise import as_notice, as_info, as_warning, as_error, as_info_label
 from cuppa.log import logger, register_secret
 from cuppa.path import split_common
 from cuppa.utility.python2to3 import as_str
@@ -111,6 +111,14 @@ class Location(object):
         return 'location_match_current_branch' in self._cuppa_env and self._cuppa_env['location_match_current_branch']
 
 
+    def location_match_branch( self ):
+        return 'location_match_branch' in self._cuppa_env and self._cuppa_env['location_match_branch']
+
+
+    def location_match_tag( self ):
+        return 'location_match_tag' in self._cuppa_env and self._cuppa_env['location_match_tag']
+
+
     @classmethod
     def remove_common_top_directory_under( cls, path ):
         dirs = os.listdir( path )
@@ -398,12 +406,29 @@ class Location(object):
 
             if self.location_match_current_branch():
                 # If relative versioning is in play and we are offline check first to see
-                # if the specified branch is available and prefer that one
+                # if the specified branch or tag is available and prefer that one
                 if self._supports_relative_versioning and self._current_branch:
                     branched_local_directory = local_directory + "@" + self._current_branch
                     if os.path.exists( branched_local_directory ):
                         return branched_local_directory
 
+                elif self._supports_relative_versioning and self._current_revision:
+                    branched_local_directory = local_directory + "@" + self._current_revision
+                    if os.path.exists( branched_local_directory ):
+                        return branched_local_directory
+
+            elif self.location_match_branch():
+                if self._supports_relative_versioning:
+                    branched_local_directory = local_directory + "@" + self.location_match_branch()
+                    if os.path.exists( branched_local_directory ):
+                        return branched_local_directory
+
+            elif self.location_match_tag():
+                if self._supports_relative_versioning:
+                    branched_local_directory = local_directory + "@" + self.location_match_tag()
+                    if os.path.exists( branched_local_directory ):
+                        return branched_local_directory
+
             elif self._supports_relative_versioning and self._default_branch:
                 branched_local_directory = local_directory + "@" + self._default_branch
                 if os.path.exists( branched_local_directory ):
@@ -551,8 +576,10 @@ class Location(object):
     def ver_rev_summary( self, branch, revision, full_url_path ):
         if branch and revision:
             version = ' rev. '.join( [ str(branch), str(revision) ] )
-        elif branch and revision:
-            version = ' rev. '.join( [ str(branch), str(revision) ] )
+        elif not branch and revision:
+            version = 'rev. ' + str(revision)
+        elif branch:
+            version = str(branch)
         else:
             version = os.path.splitext( path_leaf( unquote( full_url_path ) ) )[0]
             name, ext = os.path.splitext( version )
@@ -597,6 +624,7 @@ class Location(object):
         self._cuppa_env = cuppa_env
         self._supports_relative_versioning = False
         self._current_branch = self._cuppa_env['current_branch']
+        self._current_revision = self._cuppa_env['current_revision']
         self._offline = self.option_set('offline')
         offline = self._offline
         self._default_branch = self._cuppa_env['location_default_branch']
@@ -638,11 +666,11 @@ class Location(object):
                                  " that matches the version control type [{}]. Relative versioning will be ignored"
                                  " for this location.".format( location, vc_type ) )
                 else:
-                    branch_exists = False
                     logger.debug( "Relative branching active for [{location}] with"
-                                  " current branch [{branch}]".format(
+                                  " current branch [{branch}] and current revision [{revision}]".format(
                             location=as_info(str(location)),
-                            branch=as_info(str(self._current_branch))
+                            branch=as_info(str(self._current_branch)),
+                            revision=as_info(str(self._current_revision))
                     ) )
 
                     if self._current_branch:
@@ -653,6 +681,56 @@ class Location(object):
                             logger.trace( "scm_location = [{scm_location}]".format(
                                     scm_location=as_info(str(scm_location))
                             ) )
+                    elif self._current_revision:
+                        # Try to checkout on the explicit branch but if that fails fall back to
+                        # to the default by stripping off the '@' from the end of the path
+                        if not offline and scm_system.remote_branch_exists( repo_location, self._current_revision ):
+                            scm_location = location + self._current_revision
+                            logger.trace( "scm_location = [{scm_location}]".format(
+                                    scm_location=as_info(str(scm_location))
+                            ) )
+
+            elif self.location_match_branch():
+                if not scm_system:
+                    logger.warn( "Location [{}] specified using relative versioning, but no SCM system is available"
+                                 " that matches the version control type [{}]. Relative versioning will be ignored"
+                                 " for this location.".format( location, vc_type ) )
+                else:
+                    logger.debug( "Relative branching active for [{location}] with"
+                                  " branch [{branch}]".format(
+                            location=as_info(str(location)),
+                            branch=as_info(str(self.location_match_branch()))
+                    ) )
+
+                    if self.location_match_branch():
+                        # Try to checkout on the explicit branch but if that fails fall back to
+                        # to the default by stripping off the '@' from the end of the path
+                        if not offline and scm_system.remote_branch_exists( repo_location, self.location_match_branch() ):
+                            scm_location = location + self.location_match_branch()
+                            logger.trace( "scm_location = [{scm_location}]".format(
+                                    scm_location=as_info(str(scm_location))
+                            ) )
+
+            elif self.location_match_tag():
+                if not scm_system:
+                    logger.warn( "Location [{}] specified using relative versioning, but no SCM system is available"
+                                 " that matches the version control type [{}]. Relative versioning will be ignored"
+                                 " for this location.".format( location, vc_type ) )
+                else:
+                    logger.debug( "Relative tagging active for [{location}] with"
+                                  " tag [{revision}]".format(
+                            location=as_info(str(location)),
+                            revision=as_info(str(self.location_match_tag()))
+                    ) )
+
+                    if self.location_match_tag():
+                        # Try to checkout on the explicit branch but if that fails fall back to
+                        # to the default by stripping off the '@' from the end of the path
+                        if not offline and scm_system.remote_branch_exists( repo_location, self.location_match_tag() ):
+                            scm_location = location + self.location_match_tag()
+                            logger.trace( "scm_location = [{scm_location}]".format(
+                                    scm_location=as_info(str(scm_location))
+                            ) )
 
             elif scm_system and not offline:
                 self._default_branch = scm_system.remote_default_branch( repo_location )
