@@ -42,6 +42,7 @@ class Gcc(object):
     def supported_versions( cls ):
         return [
             "gcc",
+            "gcc11", "gcc111",
             "gcc10", "gcc102", "gcc101",
             "gcc9", "gcc93", "gcc92", "gcc91",
             "gcc8", "gcc83", "gcc82", "gcc81",
@@ -552,6 +553,16 @@ class Gcc(object):
             'line'      : None,
             'column'    : None,
         },
+        {
+            'title'     : "In",
+            'regex'     : r"([][{}() \t#%@$~\w&_:+/\.-]+)(:([0-9]+):[0-9]+)(:[ \t]+in .*)",
+            'meaning'   : 'message',
+            'highlight' : set( [ 1, 2 ] ),
+            'display'   : [ 1, 2, 4 ],
+            'file'      : 1,
+            'line'      : None,
+            'column'    : None,
+        },
         {
             'title'     : "Compiler Warning 2",
             'regex'     : r"([][{}() \t#%@$~\w&_:+/\.-]+)(:([0-9]+):([0-9]+))(:[ \t]([Ww]arning:[ \t].*))",
